# -*-coding:utf-8 -*- #
# ---------------------------------------------------------------------------
# ProjectName:   test62
# FileName:      db.py
# Author:       wen
# Datetime:     2024/9/3 下午7:01
# Description:
# 
# ---------------------------------------------------------------------------

import pymysql

from Test_3 import log
from Test_3.common.basic_read_ini import ReadIni


class DB:
    def __init__(self):
        # 创建ReadIni对象
        ini = ReadIni()
        # 链接数据库
        self.conn = pymysql.connect(
            host=ini.get_sql("host"),
            port=int(ini.get_sql("port")),
            user=ini.get_sql("user"),
            password=ini.get_sql("password"),
            database=ini.get_sql("database"),
            charset="utf8"
        )
        # 获取游标对象
        self.cursor = self.conn.cursor()

    def close(self):
        # 关闭游标对象，关闭数据库
        self.cursor.close()
        self.conn.close()

    def delete(self, sql_sentence):
        # 判断删除sql语句为字符串
        if isinstance(sql_sentence, str):
            # 判断是否为delete开始
            if sql_sentence.strip().lower().startswith("delete"):
                try:
                    # 执行sql语句并提交
                    self.cursor.execute(sql_sentence)
                    self.conn.commit()
                except Exception as e:
                    log.error(f"方法delete,执行删除的sql语句{sql_sentence}产生错误，错误为：{e}")
                    raise e
            else:
                log.error(f"执行delete方法时，sql语句错误，sql语句为：{sql_sentence}")
                raise ValueError(f"删除sql语句错误")
        else:
            log.error(f"执行delete方法时，sql语句错误，sql语句为：{sql_sentence}")
            raise ValueError(f"删除sql语句错误")

    def select(self, sql_sentence, n=0):
        # 判断查询sql语句为字符串
        if isinstance(sql_sentence, str):
            # 判断是否为select开始
            if sql_sentence.strip().lower().startswith("select"):
                try:
                    # 执行sql语句并提交
                    self.cursor.execute(sql_sentence)
                    self.conn.commit()
                except Exception as e:
                    log.error(f"执行查询的sql语句{sql_sentence}产生错误，错误为：{e}")
                    raise e
                else:
                    # 接受查询结果
                    select_result = self.cursor.fetchall()
                try:
                    # 有查询结果返回查询结果，没有，返回None
                    if select_result:
                        return select_result[n][0]
                except Exception as e:
                    log.error(f"获取查询结果产生错误错误可能是n产生的，n为{n}，错误为：{e}")
                    raise e
            else:
                log.error(f"执行select方法时，sql语句不是查询的sql语句，sql语句为：{sql_sentence}")
                raise ValueError(f"sql语句错误")
        else:
            log.error(f"执行select方法时，sql语句错误，sql语句为：{sql_sentence}")
            raise ValueError(f"sql语句错误")


if __name__ == '__main__':
    sql = "select ID_ FROM uc_demension LIMIT 2"
    db = DB()
    print(db.select(sql, n=100))
