# -*-coding:utf-8 -*- #
# ---------------------------------------------------------------------------
# ProjectName:   test62
# FileName:      read_excel.py
# Author:       wen
# Datetime:     2024/8/31 上午11:24
# Description:
# 
# ---------------------------------------------------------------------------

import openpyxl

from Test_3 import log
from Test_3.common.user_read_ini import ReadIni
from Test_3.common.basic_read_ini import ReadIni as BasicIni
from Test_3.common.read_json import read_json
from Test_3.data_config.settings import *


class ReadExcel:
    def __init__(self, username):
        # 创建ReadIni对象
        self.ini = ReadIni(username)
        # 获取excel的路径
        excel_path = self.ini.get_file_path(FILE_EXCEL)
        # 获取工作表名称
        table_name = self.ini.get_table(TABLE_KEY)
        # 获取json文件路径
        case_data_path = self.ini.get_file_path(FILE_CASE)
        expect_data_path = self.ini.get_file_path(FILE_EXPECT)
        sql_data_path = self.ini.get_file_path(FILE_SQL)
        # 读取json文件
        self.case_data_dict = read_json(case_data_path)
        self.expect_data_dict = read_json(expect_data_path)
        self.sql_data_dict = read_json(sql_data_path)
        try:
            # 加载工作簿
            wb = openpyxl.load_workbook(excel_path)
            self.ws = wb[table_name]
        except Exception as e:
            log.error(f"ini配置文件中的配置项填写错误，可能excel的文件名称{excel_path}错误，也可能工作表名称{table_name}错误，错误为：{e}")
            raise e

    def __get_cell_value(self, column, row):
        try:
            # 获取列表中的列行值（F1..）
            cell_value = self.ws[column + str(row)].value
        except Exception as e:
            log.error(f"获取{column}列的第{row}行的数据，产生错误，错误为：{e}")
            raise e
        else:
            # 判断单元格数据是否为None，如果为none，返回None
            if cell_value is None:
                return None
            # 判断单元格数据去掉前后空白字符后是否为空，如果为空，返回None，不为空，去掉前后空格后返回
            elif cell_value.strip():
                return cell_value.strip()

    def get_case_url(self, row):
        # 获取excel里的用例路径
        path = self.__get_cell_value(URL, row)
        # 判断用例路径是否为空，不为空，进行拼接，为空，返回None
        if path:
            # ReadIni对象调用get_host获取域名
            # 返回拼接路径
            return BasicIni().get_host(HOST_KEY) + path

    def get_request_method(self, row):
        # 获取用例中的请求方法
        return self.__get_cell_value(REQ_METHOD, row)

    def get_request_mime(self, row):
        # 获取用例的请求的媒体类型
        mime = self.__get_cell_value(MIME, row)
        # 判断是否为空，不为空，转小写返回，为空，返回None
        # 结果1 if bool表达式 else 结果2
        # return mime.lower() if mime else None
        if mime:
            return mime.lower()

    def get_module_name(self, row):
        # 根据行号，获取模块名称
        return self.__get_cell_value(MODULE, row)

    def get_api_name(self, row):
        # 根据行号，获取接口名称
        return self.__get_cell_value(API, row)

    def get_case_data(self, row):
        # 获取用例数据的key
        case_data_key = self.__get_cell_value(CASE_DATA, row)
        # 判断是否为None，如果为空，返回None，不为空，获取key
        if case_data_key:
            # 获取用例的模块名称，接口名称
            module_name = self.get_module_name(row)
            api_name = self.get_api_name(row)
            # 根据模块名称，接口名称，用例数据的key获取用例数据
            return self.case_data_dict[module_name][api_name][case_data_key]

    def get_expect_data(self, row):
        # 获取excel里期望数据的key
        expect_data_key = self.__get_cell_value(EXPECT_DATA, row)
        if expect_data_key:
            # 获取期望数据的模块名称，接口名称
            module_name = self.get_module_name(row)
            api_name = self.get_api_name(row)
            # 根据模块名称，接口名称，期望的key获取期望数据
            return self.expect_data_dict[module_name][api_name][expect_data_key]

    def get_sql_data(self, row):
        # 获取excel里期望数据的key
        sql_data_key = self.__get_cell_value(SQL_DATA, row)
        if sql_data_key:
            # 获取期望数据的模块名称，接口名称
            module_name = self.get_module_name(row)
            api_name = self.get_api_name(row)
            # 根据模块名称，接口名称，期望的key获取期望数据
            return self.sql_data_dict[module_name][api_name][sql_data_key]

    def get_sql_type(self, row):
        # 获取sql语句类型的值
        sql = self.__get_cell_value(SQL_TYPE, row)
        # 判断是否为空，不为空，转小写返回，为空，返回None
        if sql:
            return sql.lower()

    def get_update_key(self, row):
        # 获取更新的key
        return self.__get_cell_value(UPDATE_KEY, row)

    def get_case_title(self, row):
        # 获取用例标题
        return self.__get_cell_value(TITLE, row)

    def get_case_level(self, row):
        # 获取用例等级
        return self.__get_cell_value(LEVEL, row)

    def get_data(self):
        # 创建一个空列表存放工作表中的数据
        list_data = []
        # 循环工作表中的数据行
        for row in range(2, self.ws.max_row+1):
            # 根据行号，获取每行的测试数据
            module_name = self.get_module_name(row)
            api_name = self.get_api_name(row)
            title = self.get_case_title(row)
            level = self.get_case_level(row)
            # 请求路径
            url = self.get_case_url(row)
            # 请求方法
            method = self.get_request_method(row)
            # 请求媒体类型
            mime = self.get_request_mime(row)
            # 用例数据
            case_data = self.get_case_data(row)
            # 期望数据，做断言
            expect_data = self.get_expect_data(row)
            # sql语句类型
            sql_type = self.get_sql_type(row)
            # sql语句数据
            sql_data = self.get_sql_data(row)
            # 更新的key
            update_key = self.get_update_key(row)
            # 过滤空行，请求路径，方法，媒体类型都不为空，表示不是空行
            if url is not None and method is not None and expect_data is not None:
                # 将获取的数据放在一个空列表中，再将列表追加到前面的空列表中
                list_data.append(
                    [module_name, api_name, title, level, url, method, mime, case_data, expect_data, sql_type, sql_data, update_key])
        else:
            return list_data


if __name__ == '__main__':
    excel = ReadExcel("demo")
    # print(excel.get_case_data(12))
    # print(excel.get_expect_data(12))
    # print(excel.get_sql_data(12))
    print(excel.get_data())
